==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/chat/ChatBuilder.java <==
package it.auties.whatsapp.model.chat;

public class ChatBuilder {
    private it.auties.whatsapp.model.jid.Jid jid;
    private it.auties.whatsapp.util.ConcurrentLinkedHashedDequeue<it.auties.whatsapp.model.sync.HistorySyncMessage> historySyncMessages;
    private it.auties.whatsapp.model.jid.Jid newJid;
    private it.auties.whatsapp.model.jid.Jid oldJid;
    private int unreadMessagesCount;
    private boolean readOnly;
    private boolean endOfHistoryTransfer;
    private it.auties.whatsapp.model.chat.ChatEphemeralTimer ephemeralMessageDuration;
    private long ephemeralMessagesToggleTimeSeconds;
    private it.auties.whatsapp.model.chat.Chat.EndOfHistoryTransferType endOfHistoryTransferType;
    private long timestampSeconds;
    private java.lang.String name;
    private boolean notSpam;
    private boolean archived;
    private it.auties.whatsapp.model.chat.ChatDisappear disappearInitiator;
    private boolean markedAsUnread;
    private java.util.List<it.auties.whatsapp.model.chat.GroupParticipant> participants;
    private byte[] token;
    private long tokenTimestampSeconds;
    private byte[] identityKey;
    private int pinnedTimestampSeconds;
    private it.auties.whatsapp.model.chat.ChatMute mute;
    private it.auties.whatsapp.model.chat.ChatWallpaper wallpaper;
    private it.auties.whatsapp.model.media.MediaVisibility mediaVisibility;
    private long tokenSenderTimestampSeconds;
    private boolean suspended;
    private boolean terminated;
    private long foundationTimestampSeconds;
    private it.auties.whatsapp.model.jid.Jid founder;
    private java.lang.String description;
    private boolean support;
    private boolean parentGroup;
    private boolean defaultSubGroup;
    private it.auties.whatsapp.model.jid.Jid parentGroupJid;
    private java.lang.String displayName;
    private it.auties.whatsapp.model.jid.Jid phoneJid;
    private boolean shareOwnPhoneNumber;
    private boolean pnhDuplicateLidThread;
    private it.auties.whatsapp.model.jid.Jid lidJid;

    public ChatBuilder() {
        jid = null;
        historySyncMessages = new it.auties.whatsapp.util.ConcurrentLinkedHashedDequeue<it.auties.whatsapp.model.sync.HistorySyncMessage>();
        newJid = null;
        oldJid = null;
        unreadMessagesCount = 0;
        readOnly = false;
        endOfHistoryTransfer = false;
        ephemeralMessageDuration = null;
        ephemeralMessagesToggleTimeSeconds = 0l;
        endOfHistoryTransferType = null;
        timestampSeconds = 0l;
        name = null;
        notSpam = false;
        archived = false;
        disappearInitiator = null;
        markedAsUnread = false;
        participants = new java.util.ArrayList<it.auties.whatsapp.model.chat.GroupParticipant>();
        token = null;
        tokenTimestampSeconds = 0l;
        identityKey = null;
        pinnedTimestampSeconds = 0;
        mute = null;
        wallpaper = null;
        mediaVisibility = null;
        tokenSenderTimestampSeconds = 0l;
        suspended = false;
        terminated = false;
        foundationTimestampSeconds = 0l;
        founder = null;
        description = null;
        support = false;
        parentGroup = false;
        defaultSubGroup = false;
        parentGroupJid = null;
        displayName = null;
        phoneJid = null;
        shareOwnPhoneNumber = false;
        pnhDuplicateLidThread = false;
        lidJid = null;
    }

    public ChatBuilder jid(it.auties.whatsapp.model.jid.Jid jid) {
        this.jid = jid;
        return this;
    }
    public ChatBuilder historySyncMessages(it.auties.whatsapp.util.ConcurrentLinkedHashedDequeue<it.auties.whatsapp.model.sync.HistorySyncMessage> historySyncMessages) {
        this.historySyncMessages = historySyncMessages;
        return this;
    }
    public ChatBuilder newJid(it.auties.whatsapp.model.jid.Jid newJid) {
        this.newJid = newJid;
        return this;
    }
    public ChatBuilder oldJid(it.auties.whatsapp.model.jid.Jid oldJid) {
        this.oldJid = oldJid;
        return this;
    }
    public ChatBuilder unreadMessagesCount(int unreadMessagesCount) {
        this.unreadMessagesCount = unreadMessagesCount;
        return this;
    }
    public ChatBuilder readOnly(boolean readOnly) {
        this.readOnly = readOnly;
        return this;
    }
    public ChatBuilder endOfHistoryTransfer(boolean endOfHistoryTransfer) {
        this.endOfHistoryTransfer = endOfHistoryTransfer;
        return this;
    }
    public ChatBuilder ephemeralMessageDuration(it.auties.whatsapp.model.chat.ChatEphemeralTimer ephemeralMessageDuration) {
        this.ephemeralMessageDuration = ephemeralMessageDuration;
        return this;
    }
    public ChatBuilder ephemeralMessagesToggleTimeSeconds(long ephemeralMessagesToggleTimeSeconds) {
        this.ephemeralMessagesToggleTimeSeconds = ephemeralMessagesToggleTimeSeconds;
        return this;
    }
    public ChatBuilder endOfHistoryTransferType(it.auties.whatsapp.model.chat.Chat.EndOfHistoryTransferType endOfHistoryTransferType) {
        this.endOfHistoryTransferType = endOfHistoryTransferType;
        return this;
    }
    public ChatBuilder timestampSeconds(long timestampSeconds) {
        this.timestampSeconds = timestampSeconds;
        return this;
    }
    public ChatBuilder name(java.lang.String name) {
        this.name = name;
        return this;
    }
    public ChatBuilder notSpam(boolean notSpam) {
        this.notSpam = notSpam;
        return this;
    }
    public ChatBuilder archived(boolean archived) {
        this.archived = archived;
        return this;
    }
    public ChatBuilder disappearInitiator(it.auties.whatsapp.model.chat.ChatDisappear disappearInitiator) {
        this.disappearInitiator = disappearInitiator;
        return this;
    }
    public ChatBuilder markedAsUnread(boolean markedAsUnread) {
        this.markedAsUnread = markedAsUnread;
        return this;
    }
    public ChatBuilder participants(java.util.List<it.auties.whatsapp.model.chat.GroupParticipant> participants) {
        this.participants = participants;
        return this;
    }
    public ChatBuilder token(byte[] token) {
        this.token = token;
        return this;
    }
    public ChatBuilder tokenTimestampSeconds(long tokenTimestampSeconds) {
        this.tokenTimestampSeconds = tokenTimestampSeconds;
        return this;
    }
    public ChatBuilder identityKey(byte[] identityKey) {
        this.identityKey = identityKey;
        return this;
    }
    public ChatBuilder pinnedTimestampSeconds(int pinnedTimestampSeconds) {
        this.pinnedTimestampSeconds = pinnedTimestampSeconds;
        return this;
    }
    public ChatBuilder mute(it.auties.whatsapp.model.chat.ChatMute mute) {
        this.mute = mute;
        return this;
    }
    public ChatBuilder wallpaper(it.auties.whatsapp.model.chat.ChatWallpaper wallpaper) {
        this.wallpaper = wallpaper;
        return this;
    }
    public ChatBuilder mediaVisibility(it.auties.whatsapp.model.media.MediaVisibility mediaVisibility) {
        this.mediaVisibility = mediaVisibility;
        return this;
    }
    public ChatBuilder tokenSenderTimestampSeconds(long tokenSenderTimestampSeconds) {
        this.tokenSenderTimestampSeconds = tokenSenderTimestampSeconds;
        return this;
    }
    public ChatBuilder suspended(boolean suspended) {
        this.suspended = suspended;
        return this;
    }
    public ChatBuilder terminated(boolean terminated) {
        this.terminated = terminated;
        return this;
    }
    public ChatBuilder foundationTimestampSeconds(long foundationTimestampSeconds) {
        this.foundationTimestampSeconds = foundationTimestampSeconds;
        return this;
    }
    public ChatBuilder founder(it.auties.whatsapp.model.jid.Jid founder) {
        this.founder = founder;
        return this;
    }
    public ChatBuilder description(java.lang.String description) {
        this.description = description;
        return this;
    }
    public ChatBuilder support(boolean support) {
        this.support = support;
        return this;
    }
    public ChatBuilder parentGroup(boolean parentGroup) {
        this.parentGroup = parentGroup;
        return this;
    }
    public ChatBuilder defaultSubGroup(boolean defaultSubGroup) {
        this.defaultSubGroup = defaultSubGroup;
        return this;
    }
    public ChatBuilder parentGroupJid(it.auties.whatsapp.model.jid.Jid parentGroupJid) {
        this.parentGroupJid = parentGroupJid;
        return this;
    }
    public ChatBuilder displayName(java.lang.String displayName) {
        this.displayName = displayName;
        return this;
    }
    public ChatBuilder phoneJid(it.auties.whatsapp.model.jid.Jid phoneJid) {
        this.phoneJid = phoneJid;
        return this;
    }
    public ChatBuilder shareOwnPhoneNumber(boolean shareOwnPhoneNumber) {
        this.shareOwnPhoneNumber = shareOwnPhoneNumber;
        return this;
    }
    public ChatBuilder pnhDuplicateLidThread(boolean pnhDuplicateLidThread) {
        this.pnhDuplicateLidThread = pnhDuplicateLidThread;
        return this;
    }
    public ChatBuilder lidJid(it.auties.whatsapp.model.jid.Jid lidJid) {
        this.lidJid = lidJid;
        return this;
    }

    public it.auties.whatsapp.model.chat.Chat build() {
        return new it.auties.whatsapp.model.chat.Chat(jid, historySyncMessages, newJid, oldJid, unreadMessagesCount, readOnly, endOfHistoryTransfer, ephemeralMessageDuration, ephemeralMessagesToggleTimeSeconds, endOfHistoryTransferType, timestampSeconds, name, notSpam, archived, disappearInitiator, markedAsUnread, participants, token, tokenTimestampSeconds, identityKey, pinnedTimestampSeconds, mute, wallpaper, mediaVisibility, tokenSenderTimestampSeconds, suspended, terminated, foundationTimestampSeconds, founder, description, support, parentGroup, defaultSubGroup, parentGroupJid, displayName, phoneJid, shareOwnPhoneNumber, pnhDuplicateLidThread, lidJid);
    }
}

==> cobalt-0.0.2-sources.jar: it/auties/whatsapp/model/chat/ChatBuilder.java <==
package it.auties.whatsapp.model.chat;

public class ChatBuilder {
    private it.auties.whatsapp.model.jid.Jid jid;
    private it.auties.whatsapp.util.ConcurrentLinkedHashedDequeue<it.auties.whatsapp.model.sync.HistorySyncMessage> historySyncMessages;
    private it.auties.whatsapp.model.jid.Jid newJid;
    private it.auties.whatsapp.model.jid.Jid oldJid;
    private int unreadMessagesCount;
    private boolean readOnly;
    private boolean endOfHistoryTransfer;
    private it.auties.whatsapp.model.chat.ChatEphemeralTimer ephemeralMessageDuration;
    private long ephemeralMessagesToggleTimeSeconds;
    private it.auties.whatsapp.model.chat.Chat.EndOfHistoryTransferType endOfHistoryTransferType;
    private long timestampSeconds;
    private java.lang.String name;
    private boolean notSpam;
    private boolean archived;
    private it.auties.whatsapp.model.chat.ChatDisappear disappearInitiator;
    private boolean markedAsUnread;
    private java.util.List<it.auties.whatsapp.model.chat.GroupParticipant> participants;
    private byte[] token;
    private long tokenTimestampSeconds;
    private byte[] identityKey;
    private int pinnedTimestampSeconds;
    private it.auties.whatsapp.model.chat.ChatMute mute;
    private it.auties.whatsapp.model.chat.ChatWallpaper wallpaper;
    private it.auties.whatsapp.model.media.MediaVisibility mediaVisibility;
    private long tokenSenderTimestampSeconds;
    private boolean suspended;
    private boolean terminated;
    private long foundationTimestampSeconds;
    private it.auties.whatsapp.model.jid.Jid founder;
    private java.lang.String description;
    private boolean support;
    private boolean parentGroup;
    private boolean defaultSubGroup;
    private it.auties.whatsapp.model.jid.Jid parentGroupJid;
    private java.lang.String displayName;
    private it.auties.whatsapp.model.jid.Jid phoneJid;
    private boolean shareOwnPhoneNumber;
    private boolean pnhDuplicateLidThread;
    private it.auties.whatsapp.model.jid.Jid lidJid;
    private java.util.concurrent.ConcurrentHashMap<it.auties.whatsapp.model.jid.Jid,it.auties.whatsapp.model.contact.ContactStatus> presences;
    private java.util.Set<it.auties.whatsapp.model.jid.Jid> participantsPreKeys;
    private java.util.Set<it.auties.whatsapp.model.chat.GroupPastParticipant> pastParticipants;

    public ChatBuilder() {
        jid = null;
        historySyncMessages = new it.auties.whatsapp.util.ConcurrentLinkedHashedDequeue<it.auties.whatsapp.model.sync.HistorySyncMessage>();
        newJid = null;
        oldJid = null;
        unreadMessagesCount = 0;
        readOnly = false;
        endOfHistoryTransfer = false;
        ephemeralMessageDuration = null;
        ephemeralMessagesToggleTimeSeconds = 0l;
        endOfHistoryTransferType = null;
        timestampSeconds = 0l;
        name = null;
        notSpam = false;
        archived = false;
        disappearInitiator = null;
        markedAsUnread = false;
        participants = new java.util.ArrayList<it.auties.whatsapp.model.chat.GroupParticipant>();
        token = null;
        tokenTimestampSeconds = 0l;
        identityKey = null;
        pinnedTimestampSeconds = 0;
        mute = null;
        wallpaper = null;
        mediaVisibility = null;
        tokenSenderTimestampSeconds = 0l;
        suspended = false;
        terminated = false;
        foundationTimestampSeconds = 0l;
        founder = null;
        description = null;
        support = false;
        parentGroup = false;
        defaultSubGroup = false;
        parentGroupJid = null;
        displayName = null;
        phoneJid = null;
        shareOwnPhoneNumber = false;
        pnhDuplicateLidThread = false;
        lidJid = null;
        presences = new java.util.concurrent.ConcurrentHashMap<it.auties.whatsapp.model.jid.Jid,it.auties.whatsapp.model.contact.ContactStatus>();
        participantsPreKeys = new java.util.HashSet<it.auties.whatsapp.model.jid.Jid>();
        pastParticipants = new java.util.HashSet<it.auties.whatsapp.model.chat.GroupPastParticipant>();
    }

    public ChatBuilder jid(it.auties.whatsapp.model.jid.Jid jid) {
        this.jid = jid;
        return this;
    }
    public ChatBuilder historySyncMessages(it.auties.whatsapp.util.ConcurrentLinkedHashedDequeue<it.auties.whatsapp.model.sync.HistorySyncMessage> historySyncMessages) {
        this.historySyncMessages = historySyncMessages;
        return this;
    }
    public ChatBuilder newJid(it.auties.whatsapp.model.jid.Jid newJid) {
        this.newJid = newJid;
        return this;
    }
    public ChatBuilder oldJid(it.auties.whatsapp.model.jid.Jid oldJid) {
        this.oldJid = oldJid;
        return this;
    }
    public ChatBuilder unreadMessagesCount(int unreadMessagesCount) {
        this.unreadMessagesCount = unreadMessagesCount;
        return this;
    }
    public ChatBuilder readOnly(boolean readOnly) {
        this.readOnly = readOnly;
        return this;
    }
    public ChatBuilder endOfHistoryTransfer(boolean endOfHistoryTransfer) {
        this.endOfHistoryTransfer = endOfHistoryTransfer;
        return this;
    }
    public ChatBuilder ephemeralMessageDuration(it.auties.whatsapp.model.chat.ChatEphemeralTimer ephemeralMessageDuration) {
        this.ephemeralMessageDuration = ephemeralMessageDuration;
        return this;
    }
    public ChatBuilder ephemeralMessagesToggleTimeSeconds(long ephemeralMessagesToggleTimeSeconds) {
        this.ephemeralMessagesToggleTimeSeconds = ephemeralMessagesToggleTimeSeconds;
        return this;
    }
    public ChatBuilder endOfHistoryTransferType(it.auties.whatsapp.model.chat.Chat.EndOfHistoryTransferType endOfHistoryTransferType) {
        this.endOfHistoryTransferType = endOfHistoryTransferType;
        return this;
    }
    public ChatBuilder timestampSeconds(long timestampSeconds) {
        this.timestampSeconds = timestampSeconds;
        return this;
    }
    public ChatBuilder name(java.lang.String name) {
        this.name = name;
        return this;
    }
    public ChatBuilder notSpam(boolean notSpam) {
        this.notSpam = notSpam;
        return this;
    }
    public ChatBuilder archived(boolean archived) {
        this.archived = archived;
        return this;
    }
    public ChatBuilder disappearInitiator(it.auties.whatsapp.model.chat.ChatDisappear disappearInitiator) {
        this.disappearInitiator = disappearInitiator;
        return this;
    }
    public ChatBuilder markedAsUnread(boolean markedAsUnread) {
        this.markedAsUnread = markedAsUnread;
        return this;
    }
    public ChatBuilder participants(java.util.List<it.auties.whatsapp.model.chat.GroupParticipant> participants) {
        this.participants = participants;
        return this;
    }
    public ChatBuilder token(byte[] token) {
        this.token = token;
        return this;
    }
    public ChatBuilder tokenTimestampSeconds(long tokenTimestampSeconds) {
        this.tokenTimestampSeconds = tokenTimestampSeconds;
        return this;
    }
    public ChatBuilder identityKey(byte[] identityKey) {
        this.identityKey = identityKey;
        return this;
    }
    public ChatBuilder pinnedTimestampSeconds(int pinnedTimestampSeconds) {
        this.pinnedTimestampSeconds = pinnedTimestampSeconds;
        return this;
    }
    public ChatBuilder mute(it.auties.whatsapp.model.chat.ChatMute mute) {
        this.mute = mute;
        return this;
    }
    public ChatBuilder wallpaper(it.auties.whatsapp.model.chat.ChatWallpaper wallpaper) {
        this.wallpaper = wallpaper;
        return this;
    }
    public ChatBuilder mediaVisibility(it.auties.whatsapp.model.media.MediaVisibility mediaVisibility) {
        this.mediaVisibility = mediaVisibility;
        return this;
    }
    public ChatBuilder tokenSenderTimestampSeconds(long tokenSenderTimestampSeconds) {
        this.tokenSenderTimestampSeconds = tokenSenderTimestampSeconds;
        return this;
    }
    public ChatBuilder suspended(boolean suspended) {
        this.suspended = suspended;
        return this;
    }
    public ChatBuilder terminated(boolean terminated) {
        this.terminated = terminated;
        return this;
    }
    public ChatBuilder foundationTimestampSeconds(long foundationTimestampSeconds) {
        this.foundationTimestampSeconds = foundationTimestampSeconds;
        return this;
    }
    public ChatBuilder founder(it.auties.whatsapp.model.jid.Jid founder) {
        this.founder = founder;
        return this;
    }
    public ChatBuilder description(java.lang.String description) {
        this.description = description;
        return this;
    }
    public ChatBuilder support(boolean support) {
        this.support = support;
        return this;
    }
    public ChatBuilder parentGroup(boolean parentGroup) {
        this.parentGroup = parentGroup;
        return this;
    }
    public ChatBuilder defaultSubGroup(boolean defaultSubGroup) {
        this.defaultSubGroup = defaultSubGroup;
        return this;
    }
    public ChatBuilder parentGroupJid(it.auties.whatsapp.model.jid.Jid parentGroupJid) {
        this.parentGroupJid = parentGroupJid;
        return this;
    }
    public ChatBuilder displayName(java.lang.String displayName) {
        this.displayName = displayName;
        return this;
    }
    public ChatBuilder phoneJid(it.auties.whatsapp.model.jid.Jid phoneJid) {
        this.phoneJid = phoneJid;
        return this;
    }
    public ChatBuilder shareOwnPhoneNumber(boolean shareOwnPhoneNumber) {
        this.shareOwnPhoneNumber = shareOwnPhoneNumber;
        return this;
    }
    public ChatBuilder pnhDuplicateLidThread(boolean pnhDuplicateLidThread) {
        this.pnhDuplicateLidThread = pnhDuplicateLidThread;
        return this;
    }
    public ChatBuilder lidJid(it.auties.whatsapp.model.jid.Jid lidJid) {
        this.lidJid = lidJid;
        return this;
    }
    public ChatBuilder presences(java.util.concurrent.ConcurrentHashMap<it.auties.whatsapp.model.jid.Jid,it.auties.whatsapp.model.contact.ContactStatus> presences) {
        this.presences = presences;
        return this;
    }
    public ChatBuilder participantsPreKeys(java.util.Set<it.auties.whatsapp.model.jid.Jid> participantsPreKeys) {
        this.participantsPreKeys = participantsPreKeys;
        return this;
    }
    public ChatBuilder pastParticipants(java.util.Set<it.auties.whatsapp.model.chat.GroupPastParticipant> pastParticipants) {
        this.pastParticipants = pastParticipants;
        return this;
    }

    public it.auties.whatsapp.model.chat.Chat build() {
        return new it.auties.whatsapp.model.chat.Chat(jid, historySyncMessages, newJid, oldJid, unreadMessagesCount, readOnly, endOfHistoryTransfer, ephemeralMessageDuration, ephemeralMessagesToggleTimeSeconds, endOfHistoryTransferType, timestampSeconds, name, notSpam, archived, disappearInitiator, markedAsUnread, participants, token, tokenTimestampSeconds, identityKey, pinnedTimestampSeconds, mute, wallpaper, mediaVisibility, tokenSenderTimestampSeconds, suspended, terminated, foundationTimestampSeconds, founder, description, support, parentGroup, defaultSubGroup, parentGroupJid, displayName, phoneJid, shareOwnPhoneNumber, pnhDuplicateLidThread, lidJid, presences, participantsPreKeys, pastParticipants);
    }
}
